@@ -17,7 +17,7 @@
 // Copyright (C) 2005-2007 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Martin Kretzschmar <martink@gnome.org>
-// Copyright (C) 2005, 2009, 2012, 2013, 2015, 2017-2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2009, 2012, 2013, 2015, 2017-2019, 2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006, 2007, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2008, 2009 Chris Wilson <chris@chris-wilson.co.uk>
@@ -30,6 +30,7 @@
 // Copyright (C) 2015, 2016 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
+// Copyright (C) 2020 Michal <sudolskym@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -40,6 +41,7 @@
 
 #include "config.h"
 #include <cstring>
+#include <forward_list>
 #include "CairoFontEngine.h"
 #include "CairoOutputDev.h"
 #include "GlobalParams.h"
@@ -178,10 +180,8 @@ static bool _ft_new_face_uncached(FT_Library lib, const char *filename, char *fo
 }
 
 #ifdef CAN_CHECK_OPEN_FACES
-static struct _ft_face_data
+struct _ft_face_data
 {
-    struct _ft_face_data *prev, *next, **head;
-
     int fd;
     unsigned long hash;
     size_t size;
@@ -190,7 +190,20 @@ static struct _ft_face_data
     FT_Library lib;
     FT_Face face;
     cairo_font_face_t *font_face;
-} * _ft_open_faces;
+};
+
+class _FtFaceDataProxy
+{
+    _ft_face_data *_data;
+
+public:
+    explicit _FtFaceDataProxy(_ft_face_data *data) : _data(data) { cairo_font_face_reference(_data->font_face); }
+    _FtFaceDataProxy(_FtFaceDataProxy &&) = delete;
+    ~_FtFaceDataProxy() { cairo_font_face_destroy(_data->font_face); }
+    explicit operator _ft_face_data *() { return _data; }
+};
+
+static thread_local std::forward_list<_FtFaceDataProxy> _local_open_faces;
 
 static unsigned long _djb_hash(const unsigned char *bytes, size_t len)
 {
@@ -219,13 +232,6 @@ static void _ft_done_face(void *closure)
 {
     struct _ft_face_data *data = (struct _ft_face_data *)closure;
 
-    if (data->next)
-        data->next->prev = data->prev;
-    if (data->prev)
-        data->prev->next = data->next;
-    else
-        _ft_open_faces = data->next;
-
     if (data->fd != -1) {
 #    if defined(__SUNPRO_CC) && defined(__sun) && defined(__SVR4)
         munmap((char *)data->bytes, data->size);
@@ -243,7 +249,6 @@ static void _ft_done_face(void *closure)
 
 static bool _ft_new_face(FT_Library lib, const char *filename, char *font_data, int font_data_len, FT_Face *face_out, cairo_font_face_t **font_face_out)
 {
-    struct _ft_face_data *l;
     struct stat st;
     struct _ft_face_data tmpl;
 
@@ -275,7 +280,8 @@ static bool _ft_new_face(FT_Library lib, const char *filename, char *font_data,
     tmpl.lib = lib;
     tmpl.hash = _djb_hash(tmpl.bytes, tmpl.size);
 
-    for (l = _ft_open_faces; l; l = l->next) {
+    for (_FtFaceDataProxy &face_proxy : _local_open_faces) {
+        _ft_face_data *l = static_cast<_ft_face_data *>(face_proxy);
         if (_ft_face_data_equal(l, &tmpl)) {
             if (tmpl.fd != -1) {
 #    if defined(__SUNPRO_CC) && defined(__sun) && defined(__SVR4)
@@ -307,13 +313,8 @@ static bool _ft_new_face(FT_Library lib, const char *filename, char *font_data,
         return false;
     }
 
-    l = (struct _ft_face_data *)gmallocn(1, sizeof(struct _ft_face_data));
+    struct _ft_face_data *l = (struct _ft_face_data *)gmallocn(1, sizeof(struct _ft_face_data));
     *l = tmpl;
-    l->prev = nullptr;
-    l->next = _ft_open_faces;
-    if (_ft_open_faces)
-        _ft_open_faces->prev = l;
-    _ft_open_faces = l;
 
     l->font_face = cairo_ft_font_face_create_for_ft_face(tmpl.face, FT_LOAD_NO_HINTING | FT_LOAD_NO_BITMAP);
     if (cairo_font_face_set_user_data(l->font_face, &_ft_cairo_key, l, _ft_done_face)) {
@@ -322,6 +323,12 @@ static bool _ft_new_face(FT_Library lib, const char *filename, char *font_data,
         return false;
     }
 
+    _local_open_faces.remove_if([](_FtFaceDataProxy &face_proxy) {
+        _ft_face_data *data = static_cast<_ft_face_data *>(face_proxy);
+        return cairo_font_face_get_reference_count(data->font_face) == 1;
+    });
+    _local_open_faces.emplace_front(l);
+
     *face_out = l->face;
     *font_face_out = l->font_face;
     return true;
