@@ -27,11 +27,12 @@
 // Copyright 2019, 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright 2019 Tomoyuki Kubota <himajin100000@gmail.com>
 // Copyright 2019 João Netto <joaonetto901@gmail.com>
-// Copyright 2020 Marek Kasik <mkasik@redhat.com>
+// Copyright 2020, 2021 Marek Kasik <mkasik@redhat.com>
 // Copyright 2020 Thorsten Behrens <Thorsten.Behrens@CIB.de>
 // Copyright 2020 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
 // Copyright 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
 // Copyright 2021 Theofilos Intzoglou <int.teo@gmail.com>
+// Copyright 2021 Even Rouault <even.rouault@spatialys.com>
 //
 //========================================================================
 
@@ -596,7 +597,7 @@ bool FormWidgetSignature::signDocument(const char *saveFilename, const char *cer
     updateWidgetAppearance(); // add visible signing info to appearance
 
     Object vObj(new Dict(xref));
-    Ref vref = xref->addIndirectObject(&vObj);
+    Ref vref = xref->addIndirectObject(vObj);
     if (!createSignature(vObj, vref, GooString(signerName), tmpSignature.get(), reason, location)) {
         return false;
     }
@@ -684,7 +685,7 @@ static char *setNextOffset(char *start, Goffset offset)
 
     char *p = strstr(start, "9999999999");
     if (p) {
-        strncpy(p, buf, 10); // overwrite exact size.
+        memcpy(p, buf, 10); // overwrite exact size.
         p += 10;
     } else {
         return nullptr;
@@ -1562,73 +1563,61 @@ void FormFieldText::reset(const std::vector<std::string> &excludedFields)
 
 double FormFieldText::getTextFontSize()
 {
-    std::vector<GooString *> *daToks = new std::vector<GooString *>();
-    int idx = parseDA(daToks);
+    std::vector<std::string> daToks;
+    int idx = parseDA(&daToks);
     double fontSize = -1;
     if (idx >= 0) {
         char *p = nullptr;
-        fontSize = strtod((*daToks)[idx]->c_str(), &p);
+        fontSize = strtod(daToks[idx].c_str(), &p);
         if (!p || *p)
             fontSize = -1;
     }
-    for (auto entry : *daToks) {
-        delete entry;
-    }
-    delete daToks;
     return fontSize;
 }
 
 void FormFieldText::setTextFontSize(int fontSize)
 {
     if (fontSize > 0 && obj.isDict()) {
-        std::vector<GooString *> *daToks = new std::vector<GooString *>();
-        int idx = parseDA(daToks);
+        std::vector<std::string> daToks;
+        int idx = parseDA(&daToks);
         if (idx == -1) {
             error(errSyntaxError, -1, "FormFieldText:: invalid DA object\n");
-            for (auto entry : *daToks) {
-                delete entry;
-            }
-            delete daToks;
             return;
         }
         if (defaultAppearance)
             delete defaultAppearance;
         defaultAppearance = new GooString;
-        for (std::size_t i = 0; i < daToks->size(); ++i) {
+        for (std::size_t i = 0; i < daToks.size(); ++i) {
             if (i > 0)
                 defaultAppearance->append(' ');
             if (i == (std::size_t)idx) {
                 defaultAppearance->appendf("{0:d}", fontSize);
             } else {
-                defaultAppearance->append((*daToks)[i]);
+                defaultAppearance->append(daToks[i]);
             }
         }
-        for (auto entry : *daToks) {
-            delete entry;
-        }
-        delete daToks;
         obj.dictSet("DA", Object(defaultAppearance->copy()));
         xref->setModifiedObject(&obj, ref);
         updateChildrenAppearance();
     }
 }
 
-int FormFieldText::tokenizeDA(const GooString *da, std::vector<GooString *> *daToks, const char *searchTok)
+int FormFieldText::tokenizeDA(const std::string &da, std::vector<std::string> *daToks, const char *searchTok)
 {
     int idx = -1;
-    if (da && daToks) {
-        int i = 0;
-        int j = 0;
-        while (i < da->getLength()) {
-            while (i < da->getLength() && Lexer::isSpace(da->getChar(i))) {
+    if (daToks) {
+        size_t i = 0;
+        size_t j = 0;
+        while (i < da.size()) {
+            while (i < da.size() && Lexer::isSpace(da[i])) {
                 ++i;
             }
-            if (i < da->getLength()) {
-                for (j = i + 1; j < da->getLength() && !Lexer::isSpace(da->getChar(j)); ++j) { }
-                GooString *tok = new GooString(da, i, j - i);
-                if (searchTok && !tok->cmp(searchTok))
+            if (i < da.size()) {
+                for (j = i + 1; j < da.size() && !Lexer::isSpace(da[j]); ++j) { }
+                std::string tok(da, i, j - i);
+                if (searchTok && tok == searchTok)
                     idx = daToks->size();
-                daToks->push_back(tok);
+                daToks->emplace_back(std::move(tok));
                 i = j;
             }
         }
@@ -1636,14 +1625,14 @@ int FormFieldText::tokenizeDA(const GooString *da, std::vector<GooString *> *daT
     return idx;
 }
 
-int FormFieldText::parseDA(std::vector<GooString *> *daToks)
+int FormFieldText::parseDA(std::vector<std::string> *daToks)
 {
     int idx = -1;
     if (obj.isDict()) {
         Object objDA(obj.dictLookup("DA"));
         if (objDA.isString()) {
             const GooString *da = objDA.getString();
-            idx = tokenizeDA(da, daToks, "Tf") - 1;
+            idx = tokenizeDA(da->toStr(), daToks, "Tf") - 1;
         }
     }
     return idx;
@@ -2044,6 +2033,16 @@ void FormFieldSignature::setCustomAppearanceLeftFontSize(double size)
     customAppearanceLeftFontSize = size;
 }
 
+Ref FormFieldSignature::getImageResource() const
+{
+    return imageResource;
+}
+
+void FormFieldSignature::setImageResource(const Ref imageResourceA)
+{
+    imageResource = imageResourceA;
+}
+
 void FormFieldSignature::setCertificateInfo(std::unique_ptr<X509CertificateInfo> &certInfo)
 {
     certificate_info.swap(certInfo);
@@ -2192,10 +2191,14 @@ SignatureInfo *FormFieldSignature::validateSignature(bool doVerifyCert, bool for
         hashSignedDataBlock(&signature_handler, len);
     }
 
-    signature_info->setSignerName(signature_handler.getSignerName());
+    char *signerName = signature_handler.getSignerName();
+
+    signature_info->setSignerName(signerName);
     signature_info->setSubjectDN(signature_handler.getSignerSubjectDN());
     signature_info->setHashAlgorithm(signature_handler.getHashAlgorithm());
 
+    free(signerName);
+
     if (!signature_info->isSubfilterSupported()) {
         error(errUnimplemented, 0, "Unable to validate this type of signature");
         return signature_info;
