@@ -50,6 +50,7 @@
 // Copyright (C) 2021 Mahmoud Khalil <mahmoudkhalil11@gmail.com>
 // Copyright (C) 2021 RM <rm+git@arcsin.org>
 // Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
+// Copyright (C) 2021 Marek Kasik <mkasik@redhat.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -94,6 +95,7 @@
 #include "Hints.h"
 #include "UTF.h"
 #include "JSInfo.h"
+#include "ImageEmbeddingUtils.h"
 
 //------------------------------------------------------------------------
 
@@ -164,7 +166,7 @@ PDFDoc::PDFDoc(const GooString *fileNameA, const GooString *ownerPassword, const
     file = GooFile::open(wFileName);
     gfree(wFileName);
 #else
-    file = GooFile::open(fileName);
+    file = GooFile::open(fileName->toStr());
 #endif
     if (file == nullptr) {
         // fopen() has failed.
@@ -209,7 +211,7 @@ PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, GooString *ownerPassword, Go
     if (version.dwPlatformId == VER_PLATFORM_WIN32_NT) {
         file = GooFile::open(fileNameU);
     } else {
-        file = GooFile::open(fileName);
+        file = GooFile::open(fileName->toStr());
     }
     if (!file) {
         error(errIO, -1, "Couldn't open file '{0:t}'", fileName);
@@ -635,6 +637,16 @@ std::vector<FormFieldSignature *> PDFDoc::getSignatureFields()
     return res;
 }
 
+int PDFDoc::getNumSignatureFields()
+{
+    const Form *f = catalog->getForm();
+
+    if (!f)
+        return 0;
+
+    return f->getNumFields();
+}
+
 void PDFDoc::displayPage(OutputDev *out, int page, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, bool printing, bool (*abortCheckCbk)(void *data), void *abortCheckCbkData,
                          bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data), void *annotDisplayDecideCbkData, bool copyXRef)
 {
@@ -663,11 +675,11 @@ void PDFDoc::displayPageSlice(OutputDev *out, int page, double hDPI, double vDPI
         getPage(page)->displaySlice(out, hDPI, vDPI, rotate, useMediaBox, crop, sliceX, sliceY, sliceW, sliceH, printing, abortCheckCbk, abortCheckCbkData, annotDisplayDecideCbk, annotDisplayDecideCbkData, copyXRef);
 }
 
-Links *PDFDoc::getLinks(int page)
+std::unique_ptr<Links> PDFDoc::getLinks(int page)
 {
     Page *p = getPage(page);
     if (!p) {
-        return new Links(nullptr);
+        return std::make_unique<Links>(nullptr);
     }
     return p->getLinks();
 }
@@ -1452,6 +1464,10 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
             stream->getDict()->set("Length", Object(tmp));
 
             // Remove Stream encoding
+            AutoFreeMemStream *internalStream = dynamic_cast<AutoFreeMemStream *>(stream);
+            if (internalStream && internalStream->isFilterRemovalForbidden()) {
+                removeFilter = false;
+            }
             if (removeFilter) {
                 stream->getDict()->remove("Filter");
             }
@@ -2122,9 +2138,20 @@ bool PDFDoc::hasJavascript()
 }
 
 bool PDFDoc::sign(const char *saveFilename, const char *certNickname, const char *password, GooString *partialFieldName, int page, const PDFRectangle &rect, const GooString &signatureText, const GooString &signatureTextLeft,
-                  double fontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth, std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const GooString *reason, const GooString *location)
+                  double fontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth, std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const GooString *reason, const GooString *location,
+                  const std::string &imagePath)
 {
     ::Page *destPage = getPage(page);
+    if (destPage == nullptr) {
+        return false;
+    }
+    Ref imageResourceRef = Ref::INVALID();
+    if (!imagePath.empty()) {
+        imageResourceRef = ImageEmbeddingUtils::embed(xref, imagePath);
+        if (imageResourceRef == Ref::INVALID()) {
+            return false;
+        }
+    }
 
     const DefaultAppearance da { { objName, "SigFont" }, fontSize, std::move(fontColor) };
 
@@ -2143,13 +2170,13 @@ bool PDFDoc::sign(const char *saveFilename, const char *certNickname, const char
     GooString *daStr = da.toAppearanceString();
     annotObj.dictSet("DA", Object(daStr));
 
-    const Ref ref = getXRef()->addIndirectObject(&annotObj);
+    const Ref ref = getXRef()->addIndirectObject(annotObj);
     catalog->addFormToAcroForm(ref);
 
     std::unique_ptr<::FormFieldSignature> field = std::make_unique<::FormFieldSignature>(this, Object(annotObj.getDict()), ref, nullptr, nullptr);
-
     field->setCustomAppearanceContent(signatureText);
     field->setCustomAppearanceLeftContent(signatureTextLeft);
+    field->setImageResource(imageResourceRef);
 
     Object refObj(ref);
     AnnotWidget *signatureAnnot = new AnnotWidget(this, &annotObj, &refObj, field.get());
