@@ -3,7 +3,7 @@
 // This file is under the GPLv2 or later license
 //
 // Copyright (C) 2005-2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005, 2009, 2013, 2017, 2018, 2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2009, 2013, 2017, 2018, 2020, 2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2011 Simon Kellner <kellner@kit.edu>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
@@ -128,7 +128,7 @@ bool PageLabelInfo::labelToIndex(GooString *label, int *index) const
 
         switch (interval.style) {
         case Interval::Arabic:
-            std::tie(number, ok) = fromDecimal(str + prefixLen, str + strLen, strUnicode);
+            std::tie(number, ok) = fromDecimal(label->toStr().substr(prefixLen), strUnicode);
             if (ok && number - interval.first < interval.length) {
                 *index = interval.base + number - interval.first;
                 return true;
@@ -151,6 +151,12 @@ bool PageLabelInfo::labelToIndex(GooString *label, int *index) const
             }
             break;
         case Interval::None:
+            if (interval.length == 1 && label->toStr() == interval.prefix) {
+                *index = interval.base;
+                return true;
+            } else {
+                error(errSyntaxError, -1, "asking to convert label to page index in an unknown scenario, report a bug");
+            }
             break;
         }
     }
