@@ -6,8 +6,9 @@
 //
 // Copyright 2013, 2014 Igalia S.L.
 // Copyright 2014 Luigi Scarso <luigi.scarso@gmail.com>
-// Copyright 2014, 2018, 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright 2014, 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright 2021 Adrian Johnson <ajohnson@redneon.com>
 //
 //========================================================================
 
@@ -17,6 +18,7 @@
 #include "goo/GooString.h"
 #include "MarkedContentOutputDev.h"
 #include "Object.h"
+#include "poppler_private_export.h"
 #include <vector>
 #include <set>
 
@@ -25,7 +27,7 @@ class Dict;
 class StructElement;
 class StructTreeRoot;
 
-class Attribute
+class POPPLER_PRIVATE_EXPORT Attribute
 {
 public:
     enum Type
@@ -123,11 +125,11 @@ public:
     Owner getOwner() const { return owner; }
     const char *getTypeName() const;
     const char *getOwnerName() const;
-    Object *getValue() const { return &value; }
+    const Object *getValue() const { return &value; }
     static Object *getDefaultValue(Type type);
 
     // The caller gets the ownership of the return GooString and is responsible of deleting it
-    GooString *getName() const { return type == UserProperty ? name.copy() : new GooString(getTypeName()); }
+    std::unique_ptr<GooString> getName() const { return std::make_unique<GooString>(type == UserProperty ? name.c_str() : getTypeName()); }
 
     // The revision is optional, and defaults to zero.
     unsigned int getRevision() const { return revision; }
@@ -148,8 +150,8 @@ private:
     Type type;
     Owner owner;
     unsigned int revision;
-    mutable GooString name;
-    mutable Object value;
+    GooString name;
+    Object value;
     bool hidden;
     GooString *formatted;
 
@@ -160,7 +162,7 @@ private:
     friend class StructElement;
 };
 
-class StructElement
+class POPPLER_PRIVATE_EXPORT StructElement
 {
 public:
     enum Type
@@ -328,7 +330,7 @@ public:
     {
         if (!isContent())
             return TextSpanArray();
-        MarkedContentOutputDev mcdev(getMCID());
+        MarkedContentOutputDev mcdev(getMCID(), stmRef);
         return getTextSpansInternal(mcdev);
     }
 
@@ -369,8 +371,8 @@ private:
             Ref ref;
         };
 
-        ContentData(int mcidA) : mcid(mcidA) { }
-        ContentData(const Ref r) { ref = r; }
+        explicit ContentData(int mcidA) : mcid(mcidA) { }
+        explicit ContentData(const Ref r) { ref = r; }
     };
 
     // Common data
@@ -378,6 +380,7 @@ private:
     StructTreeRoot *treeRoot;
     StructElement *parent;
     mutable Object pageRef;
+    Object stmRef;
 
     union {
         StructData *s;
