@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2021, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +29,8 @@ class EmbeddedFilesDock : public AbstractInfoDock
     Q_OBJECT
 
 public:
-    EmbeddedFilesDock(QWidget *parent = nullptr);
-    ~EmbeddedFilesDock();
+    explicit EmbeddedFilesDock(QWidget *parent = nullptr);
+    ~EmbeddedFilesDock() override;
 
     void documentLoaded() override;
     void documentClosed() override;
