@@ -705,10 +705,9 @@ std::vector<std::unique_ptr<TextBox>> Page::textList(Rotation rotate, ShouldAbor
     m_page->parentDoc->doc->displayPageSlice(&output_dev, m_page->index + 1, 72, 72, rotation, false, false, false, -1, -1, -1, -1, shouldAbortExtractionCallback ? shouldAbortExtractionInternalCallback : nullAbortCallBack, &abortHelper,
                                              nullptr, nullptr, true);
 
-    TextWordList *word_list = output_dev.makeWordList();
+    std::unique_ptr<TextWordList> word_list = output_dev.makeWordList();
 
-    if (!word_list || (shouldAbortExtractionCallback && shouldAbortExtractionCallback(closure))) {
-        delete word_list;
+    if (shouldAbortExtractionCallback && shouldAbortExtractionCallback(closure)) {
         return output_list;
     }
 
@@ -742,8 +741,6 @@ std::vector<std::unique_ptr<TextBox>> Page::textList(Rotation rotate, ShouldAbor
         text_box->m_data->nextWord = wordBoxMap.value(word->nextWord());
     }
 
-    delete word_list;
-
     return output_list;
 }
 
